==> cpupowerd-0.2.0.tar.gz: cpupowerd-0.2.0/src/libcpupowerd.h <==
/************************************************************************/
/* Copyright (C) 2008 Markus Strobl <markus.strobl@gmx.at>              */
/*                                                                      */
/* cpupowerd is free software; you can redistribute it and/or modify it */
/* under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; either version 2 of the License.       */
/*                                                                      */
/* cpupowerd is distributed in the hope that it will be useful, but     */
/* WITHOUT ANY WARRANTY; without even the implied warranty of           */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU General Public License for more details.                         */
/*                                                                      */
/* You should have received a copy of the GNU General Public License    */
/* along with GNU Emacs; see the file COPYING.  If not, write to        */
/* the Free Software Foundation, Inc., 59 Temple Place - Suite 330,     */
/* Boston, MA 02111-1307, USA.                                          */
/************************************************************************/
/* $Id: libcpupowerd.h 309 2008-11-02 13:24:50Z markus $                */
/************************************************************************/


#ifndef LIBCPUPOWERD_H
#define LIBCPUPOWERD_H

/* Defines */	
#define LIBCPUPOWERD_MODE_FOREGROUND	0
#define LIBCPUPOWERD_MODE_DAEMON		1

#define LIBCPUPOWERD_MESSAGE_INFO		2
#define LIBCPUPOWERD_MESSAGE_WARNING	1
#define LIBCPUPOWERD_MESSAGE_ERROR		0

#define LIBCPUPOWERD_OK			 		0
#define LIBCPUPOWERD_NOTOK			   -1

/* Prototypes */
int libcpupowerd_message_set_properties(char* program_name, int program_work_mode, int program_message_typ_limit);
int libcpupowerd_messages_set_default(void);
int libcpupowerd_message(int message_typ, char *message_format, ...);
int libcpupowerd_read_msr(char *msrfile, unsigned long seek_position, unsigned long *low, unsigned long *high);
int libcpupowerd_write_msr(char *msrfile, unsigned long seek_position, unsigned long long *msrvalue);
int libcpupowerd_read_cpuid(char *cpuidfile, unsigned long seek_position, unsigned long *eax, unsigned long *ebx, unsigned long *ecx, unsigned long *edx);
int libcpupowerd_read_file(char *file, unsigned long seek_position, int bytes, char *buffer, int buffer_size);
int libcpupowerd_read_file_dynamic(char *file, char **buffer, int *size);
int libcpupowerd_write_file(char *file, unsigned long seek_position, char *buffer);
int libcpupowerd_usleep(int sleep_usec);
int libcpupowerd_set_timeofday(void);
int libcpupowerd_get_timeofday_duration(long *seconds, long *useconds);
int libcpupowerd_get_integers_from_string(char *string, char delimiter, int **integers, int *quantity);
int libcpupowerd_get_timestamp(unsigned long *timestamp);
int libcpupowerd_compare_ints(const void *a, const void *b);
int libcpupowerd_get_msrfile(int cpuid, char *file, size_t size);
int libcpupowerd_get_cpuidfile(int cpuid, char *file, size_t size);
int libcpupowerd_getsysctl(char *name, void *ptr, size_t size);

#endif

==> cpupowerd-0.2.1.tar.gz: cpupowerd-0.2.1/src/libcpupowerd.h <==
/************************************************************************/
/* Copyright (C) 2008-2009 Markus Strobl <markus.strobl@gmx.at>         */
/*                                                                      */
/* cpupowerd is free software; you can redistribute it and/or modify it */
/* under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; either version 2 of the License.       */
/*                                                                      */
/* cpupowerd is distributed in the hope that it will be useful, but     */
/* WITHOUT ANY WARRANTY; without even the implied warranty of           */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU General Public License for more details.                         */
/*                                                                      */
/* You should have received a copy of the GNU General Public License    */
/* along with GNU Emacs; see the file COPYING.  If not, write to        */
/* the Free Software Foundation, Inc., 59 Temple Place - Suite 330,     */
/* Boston, MA 02111-1307, USA.                                          */
/************************************************************************/
/* $Id: libcpupowerd.h 369 2009-01-01 13:05:07Z markus $                */
/************************************************************************/


#ifndef LIBCPUPOWERD_H
#define LIBCPUPOWERD_H

/* Defines */	
#define LIBCPUPOWERD_MODE_FOREGROUND	0
#define LIBCPUPOWERD_MODE_DAEMON		1

#define LIBCPUPOWERD_MESSAGE_INFO		2
#define LIBCPUPOWERD_MESSAGE_WARNING	1
#define LIBCPUPOWERD_MESSAGE_ERROR		0

#define LIBCPUPOWERD_OK			 		0
#define LIBCPUPOWERD_NOTOK			   -1

/* Prototypes */
int libcpupowerd_message_set_properties(char* program_name, int program_work_mode, int program_message_typ_limit);
int libcpupowerd_messages_set_default(void);
int libcpupowerd_message(int message_typ, char *message_format, ...);
int libcpupowerd_read_msr(char *msrfile, unsigned long seek_position, unsigned long *low, unsigned long *high);
int libcpupowerd_write_msr(char *msrfile, unsigned long seek_position, unsigned long long *msrvalue);
int libcpupowerd_read_cpuid(char *cpuidfile, unsigned long seek_position, unsigned long *eax, unsigned long *ebx, unsigned long *ecx, unsigned long *edx);
int libcpupowerd_read_file(char *file, unsigned long seek_position, int bytes, void *buffer, int buffer_size, int *readed_bytes);
int libcpupowerd_read_file_dynamic(char *file, char **buffer, int *size);
int libcpupowerd_write_file(char *file, unsigned long seek_position, int write_bytes, void *buffer);
int libcpupowerd_usleep(int sleep_usec);
int libcpupowerd_set_timeofday(void);
int libcpupowerd_get_timeofday_duration(long *seconds, long *useconds);
int libcpupowerd_get_integers_from_string(char *string, char *parse_format, char delimiter, int **integers, int *quantity);
int libcpupowerd_get_timestamp(unsigned long *timestamp);
int libcpupowerd_compare_ints(const void *a, const void *b);
int libcpupowerd_get_msrfile(int cpuid, char *file, size_t size);
int libcpupowerd_get_cpuidfile(int cpuid, char *file, size_t size);
int libcpupowerd_getsysctl(char *name, void *ptr, size_t size);

#endif
